# -*- coding: utf-8 -*- #
# Copyright 2022 Google LLC. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""Custom errors for Cloud SCC."""

from __future__ import absolute_import
from __future__ import division
from __future__ import print_function
from __future__ import unicode_literals

from googlecloudsdk.core import exceptions as core_exceptions


class InvalidSCCInputError(core_exceptions.Error):
  """Exception raised for errors in the input."""


class InvalidNotificationConfigError(core_exceptions.Error):
  """Exception raised for errors in the input of a NotificationConfig."""


class InvalidAPIVersion(core_exceptions.Error):
  """Exception raised for invalid API version."""
